@@ -846,25 +846,25 @@ int get_path_info(t_session *session) {
 
 /* Validate URL
  */
-int validate_url(t_session *session) {
-	if (valid_uri(session->uri) == false) {
-		log_exploit_attempt(session, "invalid URL", NULL);
-#ifdef ENABLE_COMMAND
-		increment_counter(COUNTER_EXPLOIT);
-#endif
-#ifdef ENABLE_MONITOR
-		if (session->config->monitor_enabled) {
-			monitor_counter_exploit_attempt(session);
-		}
-#endif
-
-		if (session->request_method == PUT) {
-			return 403;
-		}
-		return 404;
+bool validate_url(t_session *session) {
+	if (valid_uri(session->uri)) {
+		return true;
 	}
 
-	return 200;
+	log_exploit_attempt(session, "invalid URL", NULL);
+#ifdef ENABLE_COMMAND
+	increment_counter(COUNTER_EXPLOIT);
+#endif
+#ifdef ENABLE_MONITOR
+	if (session->config->monitor_enabled) {
+		monitor_counter_exploit_attempt(session);
+	}
+#endif
+
+	session->return_code = (session->request_method == PUT) ? 403 : 404;
+	session->error_cause = ec_INVALID_URL;
+
+	return false;
 }
 
 /* Serve the client that connected to the webserver
@@ -942,8 +942,8 @@ int serve_client(t_session *session) {
 
 	/* Validate URL
 	 */
-	if ((result = validate_url(session)) != 200) {
-		return result;
+	if (validate_url(session) == false) {
+		return -1;
 	}
 
 #ifdef ENABLE_SSL
@@ -1090,8 +1090,8 @@ int serve_client(t_session *session) {
 
 	/* Validate URL again after rewrite and decoding
 	 */
-	if ((result = validate_url(session)) != 200) {
-		return result;
+	if (validate_url(session) == false) {
+		return -1;
 	}
 
 	if ((result = uri_to_path(session)) != 200) {
@@ -1325,6 +1325,18 @@ void handle_request_result(t_session *session, int result) {
 			send_code(session);
 			log_request(session, session->return_code);
 			break;
+		case ec_INVALID_URL:
+			if ((session->config->ban_on_invalid_url > 0) && (ip_allowed(&(session->ip_address), session->config->banlist_mask) != deny)) {
+				ban_ip(&(session->ip_address), session->config->ban_on_invalid_url, session->config->kick_on_ban);
+				log_system(session, "Client banned because of invalid URL");
+#ifdef ENABLE_MONITOR
+				if (session->config->monitor_enabled) {
+					monitor_counter_ban(session);
+				}
+#endif
+			}
+			send_code(session);
+			break;
 		default:
 			if (session->data_sent == false) {
 				session->return_code = 500;
