@@ -285,6 +285,7 @@ t_config *default_config(void) {
 	config->ban_on_sqli        = 0;
 	config->ban_on_timeout     = 0;
 	config->ban_on_wrong_password = 0;
+	config->ban_on_invalid_url = 0;
 	config->kick_on_ban        = false;
 	config->reban_during_ban   = false;
 	config->max_wrong_passwords = 0;
@@ -676,6 +677,10 @@ static bool system_setting(char *key, char *value, t_config *config) {
 		if ((config->ban_on_garbage = str2int(value)) != -1) {
 			return true;
 		}
+	} else if (strcmp(key, "banoninvalidurl") == 0) {
+		if ((config->ban_on_invalid_url = str2int(value)) != -1) {
+			return true;
+		}
 	} else if (strcmp(key, "banonmaxperip") == 0) {
 		if ((config->ban_on_max_per_ip = str2int(value)) != -1) {
 			return true;
